# safe-builtins
python's builtins wrapped inside rust-like [Result](https://github.com/montasaurus/result) type

> [!WARNING]
> This library doesn't depend on [original](https://github.com/rustedpy/result) python result library, instead it depends on the one maintained by [@montasaurus](https://github.com/montasaurus/result), as per this README is written, it's still labeled as experimental and unstable, so use this library at your own risk!
> This library is also in development, so expect breaking changes
